function markangle(A,B,C,M,F)
% MARKANGLE([A;B;C],MARK) or MARKANGLE(A,B,C,MARK) marks the angle
% ABC by one of the marking symbols '+ox*' or by a number of concentric 
%   arcs, or a combination of the two methods.
% MARKANGLE([A;B;C],MARK,F) or MARKANGLE(A,B,C,MARK,F) multiplies
%   the default distance of the mark (which depends on the length of the
%   lines AB and CB) by the specified factor F.
% The four marking symbols are only effective in the first position of
%   MARK.  The characters '(' or ')' are counted in all positions: the
%   count gives the number of arcs to be drawn.
% NB ABC is taken to be positive.  If you get an unwanted reflex angle,
%   exchange A and C.
global TEX UNIT SYMBOL_SEP 
if nargin<5, F=1; end
if nargin==3, F=C; end;
if nargin<4, M=B; C=A(3); B=A(2); A=A(1); end
dist=0.2*F*min(abs(A-B),abs(C-B));
t=angle(C-B); d=angle((A-B)/(C-B));
k=find(M(1)=='xo+*');
if length(k)>0, 
  X=B+exp(i*(t+d/2))*dist/1.6;
  if TEX, if k==1, symbol='$@bullet$'; 
    elseif k==2, symbol='$@circ$';
    elseif k==3, symbol='$+$';
    else symbol='$@star$';
    end;
    text(X,symbol);
  else plot(X,M(1));
  end
end
k=sum(M=='('); h=UNIT*SYMBOL_SEP;
g=exp(i*t);
for i=1:k, arc(B,B+g*dist,A); dist=dist+h;
end
