function markline(L,MARK,M)
% MARKLINE(LINE,MARK) or MARKLINE(A,B,MARK) marks LINE or the line [A;B]
%  at its centre with a MARK  specified by one or more of the symbols 
%  "|\/XVZS<>".  The mark looks like the symbol except that "S" produces 
%  a reversed "Z".  The back-quote '`' is accepted as a substitute for
%  the backslash '\'.
%  The size of the symbols is defined by globals ARROW_SIZE (for "<>")
%  and MARK_SIZE (for the others).
%  The separation between consecutive identical symbols is given by 
%  global SYMBOL_SEP.  Non-identical consecutive symbols are
%  overprinted.
if nargin==3, L=[L;MARK]; MARK=M; end
global ARROW_SIZE MARK_SIZE SYMBOL_SEP UNIT
AS=ARROW_SIZE*UNIT; MS=0.5*MARK_SIZE*UNIT; SS=SYMBOL_SEP*UNIT;
n=length(MARK); if n>1, k=sum(MARK(1:n-1)==MARK(2:n)); else k=0; end 
s=sign(diff(L)); P=(sum(L)-k*s*SYMBOL_SEP)/2;
f=exp(i*pi*30/180); g=exp(i*pi*45/180); rg=real(g);
h=exp(i*pi*60/180); rh=real(h);
for j=1:n, if MARK(j)=='\\', MARK(j)='`';  end
  if MARK(j)=='|', line(P+s*MS*i,P-s*MS*i);
  elseif MARK(j)=='<', line(P,P-s*AS*f); line(P,P-s*AS/f);
  elseif MARK(j)=='>', line(P,P+s*AS*f); line(P,P+s*AS/f);
  elseif MARK(j)=='/', line(P+s*MS*g,P-s*MS*g);  
  elseif MARK(j)=='`', line(P+s*MS/g,P-s*MS/g); 
  elseif MARK(j)=='X', line(P+s*MS*g,P-s*MS*g); 
    line(P+s*MS/g,P-s*MS/g); 
  elseif MARK(j)=='V', line(P+s*MS*(1/h-rh),P-s*MS*(1/h+rh));
    line(P-s*MS*(h-rh),P+s*MS*(h+rh));
  elseif MARK(j)=='Z', line(P+s*MS/f,P-s*MS/f);
    line(P+s*MS/f,P+MS*s*(1/f+2i*imag(f)));
    line(P-s*MS/f,P-MS*s*(1/f+2i*imag(f)));
  elseif MARK(j)=='S', line(P+s*MS*f,P-s*MS*f);
    line(P+s*MS*f,P+MS*s*(f-2i*imag(f)));
    line(P-s*MS*f,P-MS*s*(f-2i*imag(f)));
  end
  if j<n,P=P+(MARK(j)==MARK(j+1))*s*SS; end
end

